#ifndef __PROPNAME
#define __PROPNAME


#include <qdialog.h>
class QLabel;
class QPushButton;
class KLineEdit;

class NetWidget;
class Circuit;
class XDevice;

class PropName : public QDialog
{
    Q_OBJECT

public:
    PropName(QWidget *, QString, NetWidget *, Circuit *, XDevice *);

private:
    void done(int);

    QPushButton *bOK;
    QPushButton *bCancel;
    KLineEdit *devname;
    QLabel *label0;
    XDevice *dev;
    Circuit *dnet;
    NetWidget *netw;
};

#endif
